Dialog Visual Test

WHAT: A modal dialog containing form fields, with groups to describe each section. A second modal dialog with just an input and some text markup.

EXPECTED: Dialog shows up, screenreader reads the dialog's title, the word "dialog" (or equivalent), the text before the first input (description of the first section) and the label of the first, focused input. When tabbing to the next group, the screenreader should announce the description of that group, along with the label of the focused field.

For the second dialog, the behaviour should be similar, except that the whole content is read as the description of the dialog, likely causing the input's label to be read twice.

NOTE: Using `fieldset` with `legend` seems to have the same result as using `role="group"` and `aria-describedby`. The latter needs an id-attribute, offers more flexibilty in markup order and has no built-in styling.

Please share some personal information Your favorite animal Your favorite color

Some more (optional) information

Favorite food

Please enter password to continue.

Password